function [T, phi, omega] = berechneWinkel(l, phi0, omega0, t0, t1, timeStep)
    % Die Funktion berechneWinkel dient zur Simulation eines physikalischen
    % Pendels. Sie berechnet den Auslenkungswinkel phi und die
    % Winkelgeschwindigkeit omega auf einem vorgegebenen Zeitgitter
    %
    % Verwendung: [T, phi, omega] = berechneWinkel(l, phi0, omega0, t0, t1, timeStep)
    % Input:
    %  - l ist eine reelle Zahl, die die Laenge des Pendels angibt
    %  - phi0 ist der Startwert fuer den Auslenkungswinkel zum Zeitpunkt t0
    %  - omega0 ist der Startwert fuer die Winkelgeschwindigkeit zum
    %    Zeitpunkt t0
    %  - t0 ist der Startzeitpunkt
    %  - t1 ist der Endzeitpunkt
    %  - timeStep gibt den Abstand zwischen den einzelnen Zeitpunkten an,
    %    zu denen der Winkel und die Winkelgeschwindigkeit berechnet werden
    %    sollen
    %    (Bemerkung: timeStep haengt NICHT mit der Schrittweite des
    %    verwendeten ODE-Solvers zusammen. TimeStep gibt lediglich an, in
    %    welchen Zeitabstaenden der Funktionswert der berechneten Loesung
    %    angegeben werden soll)
    % Output:
    %  - T ist ein Spaltenvektor, der ein aequidistantes
    %    Gitter von Zeitpunkten zwischen t0 und t1 enthaelt; der Abstand
    %    zweier Zeitpunkte entspricht timeStep
    %  - phi ist ein Spaltenvektor, der dieselbe Groesse wie T besitzt und
    %    zu jedem Zeitpunkt in T die zugehoerige Auslenkung des Pendels
    %    als Winkel angibt
    %  - omega ist ein Spaltenvektor, der diesselbe Groesse wie T besitzt
    %    und zu jedem Zeitpunkt in T die zugehoerige Winkelgeschwindigkeit
    %    des Pendels angibt
   
    
    g = 9.81; % Ortsfaktor festlegen
    
    % rechte Seite der Differenzialgleichung:
    f = @(t,z) [z(2); - g/l * sin(z(1))];
    % Startwerte in Vektor zusammenfassen:
    z0 = [phi0; omega0];
    
    % Option fuer Matlab-ODE-Solver, z.B relative Fehlertoleranz setzen:
    options = odeset('RelTol', 1e-5);
    % Differentialgleichung integrieren lassen:
    [T,z] = ode45(f, t0:timeStep:t1, z0, options);
    
    % Die Komponenten der Loesung werden den Output-Variablen
    % zugewiesen:
    phi = z(:,1);
    omega = z(:,2);
    
end