function pendelAnimation(l, T, phi, omega)
    % Die Funktion pendelAnimation animiert ein schwingendes Pendel und
    % speichert diese Animation als avi-Video in der Datei 
    % 'pendelAnimation.avi'.
    % 
    % Verwendung: pendelAnimation(l, T, phi, omega)
    % Input:
    %  - l ist eine positive reelle Zahl, die die Laenge des Pendels angibt
    %  - T ist ein Spaltenvektor, der ein geordnetes und aequidistantes
    %    Gitter von Zeitpunkten enthaelt
    %  - phi ist ein Spaltenvektor, der dieselbe Groesse wie T besitzt und
    %    zu jedem Zeitpunkt in T die zugehoerige Auslenkung des Pendels als
    %    Winkel angibt
    %  - omega ist ein Spaltenvektor, der diesselbe Groesse wie T besitzt
    %    und zu jedem Zeitpunkt in T die zugehoerige Winkelgeschwindigkeit
    %    des Pendels angibt
    
    
    % Kartesische Koordinaten der Pendel-Position berechnen:
    x = l * sin(phi);
    y = -l * cos(phi);
    
    % Frame-Rate fuer Video berechnen:
    timeStep = T(2)-T(1); % hierfuer muss dass Zeitgitter aequidistant sein!
    framesPerSecond = 1/timeStep;
    
    % Benoetige Groesse des Koordinatensystems bestimmen:
    axisArray = [min([x;0]), max([x;0]), min([y;0]), max([y;0])];
    
    % Graphik erzeugen:
    figure, set(gcf, 'Color','white')
    % Titel der Graphik:
    title('Schwingendes Pendel')
    
    % Skalierung fuer x-Achse und y-Achse gleich waehlen
    axis equal
    % Groesse des Koordinatensystems anpassen, so dass es fuer alle Frames
    % gleich gross ist:
    axis(axisArray);
    % Achsen beschriften:
    xlabel('x')
    ylabel('y')
        
    % Verhalten des axis-Objekts beim Plotten weiterer Graphik-Objekte
    % festlegen:
    set(gca, 'nextplot','replacechildren');
    
    % Avi-Datei-Objekt erzeugen:
    aviobj = avifile('pendelAnimation.avi', 'compression', 'Cinepak');
    aviobj.fps = framesPerSecond;
    aviobj.quality = 50;
    
    % Einzelne Frames erzeugen und dem Video hinzufuegen
    for k=1:length(T)
        cla(gca) % die vorherige Zeichnung loeschen
        plot([0; x(k)], [0; y(k)]); % die Pendelschnur zeichnen
        hold on
        plot(x(k),y(k),'o') % einen Kringel am Ende des Pendels anfuegen
        
        % Beschriftung zur Laenge des Pendels und zum Startwinkel
        % hinzufuegen:
        beschriftung =  ['l = ', int2str(l), sprintf('\n'), '\phi_0= ', ...
            num2str(phi(1)/2/pi),' * 2\pi', sprintf('\n'), ...
            '\omega_0 = ', num2str(omega(1)/2/pi), ' * 2\pi'];
        text(0.97*axisArray(1)+0.03*axisArray(2), 0.90*axisArray(4) ...
            + 0.1*axisArray(3), beschriftung)
        
        % Die momentate Graphik dem Video als Frame hinzufuegen
        aviobj = addframe(aviobj, getframe(gcf));
    end
    
    close(gcf) % Graphik wieder schlieen
    
    aviobj = close(aviobj); % Avi-Datei schlieen
    
    display('Avi-Datei wurde erstellt.') % Meldung an Benutzer
    
end